@@ -54,7 +54,7 @@ last_beep=0
 
 #arrays, indexes, lenghts
 arrDataLen=4680 #(1 value/10sec for 13h), 6*13*60
-arrData=[[0]*arrDataLen, [0]*arrDataLen, [0]*arrDataLen, [0]*arrDataLen,  [0]*arrDataLen, [0]*arrDataLen] #[0]=time [1]=X, [2]=Y
+arrData=[[0]*arrDataLen, [0]*arrDataLen, [0]*arrDataLen, [0]*arrDataLen, [0]*arrDataLen] #[0]=time [1]=X, [2]=Y, [3]=X deriv, [4]=Y deriv
 arrDataTemp=[0, 0, 0] #[0]=unused, [1]=X, [2]=Y
 arrDataIndex=0
 arrLogFiles=[]
