@@ -7,6 +7,9 @@
 # Licence:         GPL
 ###########################################################################
 
+#TODO:
+#show folder somewhere
+
 import sys
 import random
 import time
@@ -129,7 +132,9 @@ def StartMeasurement():
     data.sample_index=0
     data.values_total=0
     data.arrDataIndex=0
-    data.arrData[0][0]=""
+    
+    for i in range(0,  len(data.arrData)): #clear data of old records
+        for j in range(0,  5): data.arrData[j][i]=0
     
     if(data.Mode==0):
         interval=data.sampling #normal
@@ -414,6 +419,7 @@ class frmRecordWindow(QtGui.QWidget):
             self.UpdateScreenStart()
         else: #running
             StopMeasurement()
+            self.askdumprecord()  
             self.UpdateScreenStop()
             data.test=0 # reset test mode if was active
         
@@ -454,7 +460,16 @@ class frmRecordWindow(QtGui.QWidget):
 
 
     def closeEvent(self, event):
-        #check if user wants to keep this record
+        #in case measurement is still running (user did not click on "stop")
+        if(data.run==1): 
+            StopMeasurement()
+            self.askdumprecord()            
+        StartWindow.show()
+        self.close() 
+
+
+    def askdumprecord(self):
+    #check if user wants to keep this record
         reply = QtGui.QMessageBox.question(self, 'Keep this Record?', "Do you want to keep this Record?", QtGui.QMessageBox.Yes, QtGui.QMessageBox.No)
         if reply == QtGui.QMessageBox.No:
             print "Delete logfile: "+data.logfilename
@@ -463,15 +478,6 @@ class frmRecordWindow(QtGui.QWidget):
             data.lastlogfile=data.logfilename
 #            print "lastlogfile:",  data.lastlogfile
             config.set('main', 'lastlogfile', str(data.lastlogfile))   
-            
-        #in case measurement is still running (user did not click on "stop")
-        if(data.run==1): StopMeasurement()
-        StartWindow.show()
-        self.close() 
-
-
-   
-   
 
 
 
@@ -534,6 +540,14 @@ class frmViewWindow(QtGui.QWidget):
         else: self.ui.bRaiseTrigger.setEnabled(True)
         if(data.trigger==0): self.ui.bLowerTrigger.setEnabled(False)
         else: self.ui.bLowerTrigger.setEnabled(True)
+        
+        print len(data.arrLogFiles),  (data.arrLogFiles)
+        if(len(data.arrLogFiles)<2): #disable last/next buttons if only one file in folder
+            self.ui.bNext.setEnabled(False)
+            self.ui.bLast.setEnabled(False)
+        else:
+            self.ui.bNext.setEnabled(True)
+            self.ui.bLast.setEnabled(True)
 
 
 
@@ -602,7 +616,8 @@ class frmViewWindow(QtGui.QWidget):
         if reply == QtGui.QMessageBox.Yes:
             print "Delete logfile: "+data.logfilename
             os.remove(data.logfolder+data.logfilename)    
-
+            
+            LoadFileList()
             l=len(data.arrLogFiles)
             if(l>0):
                 data.logfilename=data.arrLogFiles[l-1] #open last (youngest) log file
@@ -621,8 +636,8 @@ class frmViewWindow(QtGui.QWidget):
                 data.logfilename=tmp2[l-1]
                 data.logfolder=string.replace(tmp,  data.logfilename,  "") #get folder of selected file
                 print "Set folder=",  data.logfolder,  ", file=",  data.logfilename
-            LoadFileList()
             self.ShowLogFile()
+            self.UpdateScreen()
 
 
 
