@@ -20,6 +20,7 @@ from myFunctions2 import * #Own functions
 def StartLogfile(interval):       
     #if not on the N900, use another place for the log file 
     if(data.demo==1): data.logfolder=data.devlogfolder #folder on devel PC
+    else: data.logfolder=data.defaultlogfolder
     
     print "Logfolder:",  data.logfolder
     try:
@@ -82,8 +83,8 @@ def StopLogfile():
 ###########################################################################
 def LoadFileList():
     Show_passed_time("LoadFileList Start")
-    print "Load file list"
-    output = os.popen("cd "+data.logfolder+"; ls -C1 *.csv").read() # run ls and make the output look like a file I can read
+    print "Load list of all csv files in folder:",  data.logfolder
+    output = os.popen("cd "+str(data.logfolder)+"; ls -C1 *.csv").read() # run ls and make the output look like a file I can read
     data.arrLogFiles=output.split("\n")
     data.arrLogFiles.pop()
     print data.arrLogFiles
@@ -105,9 +106,10 @@ def LoadFileList():
 ###########################################################################
 def OpenLogFile():    
     Show_passed_time("OpenLogFile Start")
+    print "Open Log file:",  data.logfolder+data.logfilename
     file = open(data.logfolder+data.logfilename, 'r')
     data.arrDataIndex=0
-    print "Open logfile",  data.logfilename
+    ret=0
     try:
         data.Header=file.readline()
         print "Header:",  data.Header
@@ -133,19 +135,22 @@ def OpenLogFile():
             
         
         for line in file:
+#            print line
             d=string.split(line,  ", ")
             data.arrData[0][data.arrDataIndex]=d[0] #time
             data.arrData[1][data.arrDataIndex]=int(d[1]) #X
             data.arrData[2][data.arrDataIndex]=int(d[2]) #Y
             data.arrDataIndex=data.arrDataIndex+1            
-#            if(data.arrDataIndex==data.arrDataLen): 
-#                print "Stopped, array is full, file is to big"
-#                break
+            if(data.arrDataIndex==data.arrDataLen): 
+                print "Stopped, array is full, file is to big"
+                ret=1
+                break
     finally:
         file.close()
     
     print "Loaded",  str(data.arrDataIndex),  "lines"
     Show_passed_time("OpenLogFile End")
+    return ret
     
     
     
