@@ -225,9 +225,12 @@ def showGraph(self,  QtGui):
 #            if(1): #one or more movement for this pixel
 #                peak=abs(data.arrData[3][k])+abs(data.arrData[4][k])
             Y=peak*data.Yscale
+            if(Y>=data.Ysize+17): 
+                Y=data.Ysize-17
+#                print "too big:",  Y,  peak*data.Yscale
             #Draw movement line
 #            paint.setBrush(QtGui.QColor("yellow"))
-            paint.drawLine(i/Xscale, data.Ysize-Y-1-15, i/Xscale, data.Ysize-1-15)  
+            paint.drawLine(i/Xscale+1, data.Ysize-Y-1-15, i/Xscale+1, data.Ysize-1-15)  
             
             
             #fill space between yellow movement lines
@@ -259,7 +262,7 @@ def showGraph(self,  QtGui):
 #                    print "draw rect with color",  color                  
                     paint.setBrush(QtGui.QColor(color))
                     paint.setPen(QtGui.QColor(color))
-                    paint.drawRect(x0, data.Ysize-11, x1-x0, 10)                     
+                    paint.drawRect(x0+1, data.Ysize-11, x1-x0+1, 10)                     
                     paint.setPen(QtGui.QColor("yellow"))
 #                        print "=     Draw field",  x0,  x1,  data.Ysize,  color
                 lastmove=i
